@@ -83,6 +83,10 @@ void NextcloudDeckDialog::setupUi() {
     // Explicitly transfer ownership to the button (Qt 5.7 compatibility)
     ui->reloadCardListButton->setMenu(reloadMenu);
     // Menu ownership is now transferred to the button, no manual deletion needed
+
+    // Connect the archived cards checkbox signal
+    connect(ui->showArchivedCardsCheckBox, SIGNAL(toggled(bool)), this,
+            SLOT(on_showArchivedCardsCheckBox_toggled(bool)));
 }
 
 void NextcloudDeckDialog::on_saveButton_clicked() {
@@ -114,7 +118,7 @@ void NextcloudDeckDialog::on_saveButton_clicked() {
         if (cardIdToUpdate == -1) {
             MainWindow *mainWindow = MainWindow::instance();
             if (mainWindow != nullptr) {
-                mainWindow->activeNoteTextEdit()->insertPlainText(linkText);
+                mainWindow->writeToNoteTextEdit(linkText);
             }
         }
 #endif
@@ -184,8 +188,9 @@ void NextcloudDeckDialog::setupMainSplitter() {
 void NextcloudDeckDialog::refreshUi() { reloadCardList(); }
 
 void NextcloudDeckDialog::reloadCardList() {
+    ui->newItemEdit->clear();
     NextcloudDeckService nextcloudDeckService(this);
-    _cards = nextcloudDeckService.getCards();
+    _cards = nextcloudDeckService.getCards(ui->showArchivedCardsCheckBox->isChecked());
 
     qDebug() << __func__ << " - 'cards': " << _cards;
 
@@ -404,6 +409,11 @@ void NextcloudDeckDialog::searchLinkInNotes(QTreeWidgetItem *item) {
     close();
 }
 
+void NextcloudDeckDialog::on_showArchivedCardsCheckBox_toggled(bool checked) {
+    Q_UNUSED(checked)
+    reloadCardList();
+}
+
 void NextcloudDeckDialog::addCardLinkToCurrentNote(const QTreeWidgetItem *item) {
     const int cardId = item->data(0, Qt::UserRole).toInt();
     if (cardId < 1) {
@@ -417,7 +427,7 @@ void NextcloudDeckDialog::addCardLinkToCurrentNote(const QTreeWidgetItem *item)
 #ifndef INTEGRATION_TESTS
     MainWindow *mainWindow = MainWindow::instance();
     if (mainWindow != nullptr) {
-        mainWindow->activeNoteTextEdit()->insertPlainText(linkText);
+        mainWindow->writeToNoteTextEdit(linkText);
     }
 #endif
 
